@@ -51,10 +51,10 @@ class mgCal(hildondesktop.HomeItem):
         self.evbox = gtk.EventBox()
         self.lbltop = gtk.Label()
         self.lbltop.set_use_markup(True)
-        self.lbltop.set_alignment(xalign=0,yalign=0.5)
+        self.lbltop.set_justify(gtk.JUSTIFY_CENTER)
         self.lbltop.set_padding(5,5)
         self.evbox.modify_bg(gtk.STATE_NORMAL,gtk.gdk.Color(13000,13000,13000,0))
-        self.lbltop.modify_fg(gtk.STATE_NORMAL,gtk.gdk.Color(50000,40000,20000,0))
+        self.lbltop.modify_fg(gtk.STATE_NORMAL,gtk.gdk.Color(65535,65535,0,0))
         self.evbox.add(self.lbltop)
         self.hboxtop.pack_start(self.evbox,True,True,0)
         self.vbox.pack_start(self.hboxtop,False,False,0)
@@ -137,6 +137,7 @@ class mgCal(hildondesktop.HomeItem):
         self.db.execute("""create table if not exists history (hid integer primary key autoincrement,hdatetime text)""")
         self.db.execute("""create table if not exists config (email text,pw text,font text,refresh int)""")
         self.db.execute("""create table if not exists events (eid integer primary key autoincrement,hid int,start text,end text,title text,location text)""")
+        self.db.execute("""create table if not exists timeconfig(hour24 integer)""")
         print "made db"
         row = self.db.execute("""select email,pw,font,refresh from config""").fetchall()
         try:
@@ -154,11 +155,15 @@ class mgCal(hildondesktop.HomeItem):
             # insert dummy data into the table
             self.db.execute("""insert into config values ('dummy','','sans 10',0)""")
             self.db.commit()
+        try:
+            row= self.db.execute("""select hour24 from timeconfig""").fetchall()
+            self.cfg_24_clock = row2[0][0]
+        except:
+            self.cfg_24_clock = 0
         finally:
             self.data_start = 0
             self.db.close()
 
-
     ################################################
     # configure font tags etc from font desc
     def DoFontTags(self):
@@ -218,6 +223,9 @@ class mgCal(hildondesktop.HomeItem):
         font = gtk.Button(self.cfg_font)
         font.connect("clicked",self._ChooseFont,None)
         dlgS.vbox.pack_start(font,False,False,0)
+        timeformat = gtk.CheckButton("24-hour clock")
+        timeformat.set_active(self.cfg_24_clock)
+        dlgS.vbox.pack_start(timeformat,False,False,0)
         # show all widgets
         dlgS.vbox.show_all()
         # now run the dialog
@@ -226,12 +234,16 @@ class mgCal(hildondesktop.HomeItem):
             self.cfg_email = email.get_text()
             self.cfg_pw = pw.get_text()
             self.cfg_refresh = refresh.get_value_as_int()
+            self.cfg_24_clock = timeformat.get_active()
             self.db = sqlite3.connect(db_path + db_name)
             self.db.execute("""update config set email=?,pw=?,font=?,refresh=?""",(self.cfg_email,self.cfg_pw,self.cfg_font,self.cfg_refresh))
+            self.db.execute("""update timeconfig set hour24=?""",(self.cfg_24_clock,))
             self.db.commit()
             self.db.close()
         # bye bye...
         self._resetUpdateTimer()
+        self._UpdateTime()
+        self._DrawEvents()
         dlgS.destroy()
 
 
@@ -309,6 +321,10 @@ class mgCal(hildondesktop.HomeItem):
     # draw calendar events from data store
     def _DrawEvents(self):
         try:
+            if self.cfg_24_clock:
+                timeformat = '%H:%M'
+            else:
+                timeformat = '%I:%M %p'
             cur_start = datetime.date.min
             cur_end = datetime.date.min
             ls = ''
@@ -343,7 +359,8 @@ class mgCal(hildondesktop.HomeItem):
                         self.tb.insert_with_tags_by_name(iter,'\rAll Day  ','time')
                         all_day = True
                     else:
-                        self.tb.insert_with_tags_by_name(iter,sd.strftime('\r%H:%M') + ' - ' + ed.strftime('%H:%M  '),'time')
+                        print '\r' +timeformat
+                        self.tb.insert_with_tags_by_name(iter,sd.strftime('\r' + timeformat) + ' - ' + ed.strftime(timeformat + '  '),'time')
                         all_day = False
                     # now the event title
                     if row[2]:
@@ -396,7 +413,10 @@ class mgCal(hildondesktop.HomeItem):
         self._UpdateTime()
 
     def _UpdateTime(self):
-        self.lbltop.set_markup(datetime.datetime.now().strftime("<b>%d. %b %Y  %I:%M</b>"))
+        if self.cfg_24_clock != 0:
+            self.lbltop.set_markup(datetime.datetime.now().strftime('<b>%d %b %Y  %H:%M</b>'))
+        else:
+            self.lbltop.set_markup(datetime.datetime.now().strftime('<b>%d %b %Y  %I:%M %p</b>'))
         return True
     
     def _resetUpdateTimer(self):
